@@ -24,9 +24,7 @@ fn get_rename_all(attrs: &[Attribute]) -> RenameRule {
             }
 
             match parse2::<Paren<KeyValue<Ident, LitStr>>>(attr.tokens.clone()).map(|v| v.inner) {
-                Ok(kv) if kv.key.to_string() == "rename_all" => {
-                    Some(kv.value.value().parse().unwrap())
-                }
+                Ok(kv) if kv.key == "rename_all" => Some(kv.value.value().parse().unwrap()),
                 _ => None,
             }
         })
@@ -57,10 +55,35 @@ fn get_rename(attrs: &[Attribute]) -> Option<String> {
             };
         }
 
-        return None;
+        None
     })
 }
 
+fn get_skip_mode(attrs: &[Attribute]) -> (bool, bool) {
+    let mut ser = false;
+    let mut de = false;
+    for attr in attrs {
+        if attr.path.is_ident("serde") {
+            match parse2::<Paren<Meta>>(attr.tokens.clone()) {
+                Ok(Paren {
+                    inner: Meta::Path(pa),
+                }) => {
+                    if pa.is_ident("skip") {
+                        ser = true;
+                        de = true;
+                    } else if pa.is_ident("skip_serializing") {
+                        ser = true
+                    } else if pa.is_ident("skip_deserializing") {
+                        de = true
+                    }
+                }
+                Ok(..) | Err(..) => {}
+            };
+        }
+    }
+    (ser, de)
+}
+
 fn field_name(type_attrs: &[Attribute], field: &Field) -> String {
     if let Some(s) = get_rename(&field.attrs) {
         return s;
@@ -185,14 +208,11 @@ fn extract_doc(attrs: &mut Vec<Attribute>) -> String {
                 }
             }
         } else if attr.path.is_ident("doc") {
-            match parse2::<EqStr>(attr.tokens.clone()) {
-                Ok(v) => {
-                    if !comments.is_empty() {
-                        comments.push(' ');
-                    }
-                    comments.push_str(&v.value.value());
+            if let Ok(v) = parse2::<EqStr>(attr.tokens.clone()) {
+                if !comments.is_empty() {
+                    comments.push(' ');
                 }
-                _ => {}
+                comments.push_str(&v.value.value());
             };
         }
     }
@@ -208,13 +228,19 @@ fn handle_field(type_attrs: &[Attribute], f: &mut Field) -> Stmt {
 
     let desc = extract_doc(&mut f.attrs);
     let example_v = extract_example(&mut f.attrs);
+    let (skip_ser, skip_de) = get_skip_mode(&f.attrs);
 
+    if skip_ser && skip_de {
+        return q!({ {} }).parse();
+    }
     q!(
         Vars {
             name_str,
             desc,
             Type: &f.ty,
             example_v: super::quote_option(example_v),
+            skip_ser,
+            skip_de,
         },
         {
             map.insert(rweb::rt::Cow::Borrowed(name_str), {
@@ -229,6 +255,12 @@ fn handle_field(type_attrs: &[Attribute], f: &mut Field) -> Stmt {
                     if let Some(example) = example {
                         s.example = Some(example);
                     }
+                    if skip_ser {
+                        s.write_only = Some(true);
+                    }
+                    if skip_de {
+                        s.read_only = Some(true);
+                    }
                     s
                 }
             });
@@ -297,7 +329,7 @@ fn handle_fields_required(type_attrs: &[Attribute], fields: &Fields) -> Expr {
     .parse()
 }
 
-fn extract_component(attrs: &Vec<Attribute>) -> Option<String> {
+fn extract_component(attrs: &[Attribute]) -> Option<String> {
     let mut component = None;
     let mut process_nv = |nv: syn::MetaNameValue| {
         if nv.path.is_ident("component") {
@@ -412,7 +444,7 @@ pub fn derive_schema(input: DeriveInput) -> TokenStream {
             if data
                 .variants
                 .iter()
-                .all(|variant| variant.fields.len() == 0)
+                .all(|variant| variant.fields.is_empty())
             {
                 // c-like enums
 
@@ -434,6 +466,7 @@ pub fn derive_schema(input: DeriveInput) -> TokenStream {
                     .collect();
 
                 fields.push(q!(Vars { exprs }, { enum_values: vec![exprs] }).parse());
+                fields.push(q!({ schema_type: Some(rweb::openapi::Type::String) }).parse());
             } else {
                 for v in &data.variants {
                     subcomponents_handle_fields!(&v.fields);
@@ -479,7 +512,7 @@ pub fn derive_schema(input: DeriveInput) -> TokenStream {
                             Fields::Unnamed(ref f) => {
                                 //
                                 assert!(f.unnamed.len() <= 1);
-                                if f.unnamed.len() == 0 {
+                                if f.unnamed.is_empty() {
                                     return None;
                                 }
 
